]> git.immae.eu Git - github/shaarli/Shaarli.git/commitdiff
Version 0.0.35 beta:
authorSeb Sauvage <sebsauvage@sebsauvage.net>
Wed, 25 Jan 2012 11:36:08 +0000 (12:36 +0100)
committerEmilien Klein <emilien@klein.st>
Wed, 25 Jan 2012 11:36:08 +0000 (12:36 +0100)
- Corrected: Corrected a bug introduced in 0.0.34 which would improperly preprend data to URLs.

index.php
tpl/linklist.html

index 46a8c9021b07b78eecc0ba08a289ffba3c8aac8e..da2445de7675a65a6efad80cdf8183f6578a08db 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,5 +1,5 @@
 <?php
// Shaarli 0.0.34 beta - Shaare your links...
 // The personal, minimalist, super-fast, no-database delicious clone. By sebsauvage.net
 // http://sebsauvage.net/wiki/doku.php?id=php:shaarli
 // Licence: http://www.opensource.org/licenses/zlib-license.php
@@ -58,7 +58,7 @@ header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
 header("Cache-Control: no-store, no-cache, must-revalidate");
 header("Cache-Control: post-check=0, pre-check=0", false);
 header("Pragma: no-cache");
-define('shaarli_version','0.0.34 beta');
+define('shaarli_version','0.0.35 beta');
 if (!is_dir($GLOBALS['config']['DATADIR'])) { mkdir($GLOBALS['config']['DATADIR'],0705); chmod($GLOBALS['config']['DATADIR'],0705); }
 if (!is_file($GLOBALS['config']['DATADIR'].'/.htaccess')) { file_put_contents($GLOBALS['config']['DATADIR'].'/.htaccess',"Allow from none\nDeny from all\n"); } // Protect data files.
 if ($GLOBALS['config']['ENABLE_LOCALCACHE'])
index 70b9ff3ace1177952ca558cf992d839742506cf6..a7dd61e95af84f4505804d6699e535a240678b19 100644 (file)
@@ -29,7 +29,7 @@
         <li{if="$value.class"} class="{$value.class}"{/if}>
             <div class="thumbnail">{$value.url|thumbnail}</div>
             <div class="linkcontainer">
-                <span class="linktitle"><a href="{$redirector}{$value.url|urlencode}">{$value.title|htmlspecialchars}</a></span>
+                <span class="linktitle"><a href="{$redirector}{$value.url}">{$value.title|htmlspecialchars}</a></span>
                 {if="isLoggedIn()"}
                     <form method="GET" class="buttoneditform"><input type="hidden" name="edit_link" value="{$value.linkdate}"><input type="image" alt="Edit" src="images/edit_icon.png#" title="Edit" class="button_edit"></form>
                     <form method="POST" class="buttoneditform"><input type="hidden" name="lf_linkdate" value="{$value.linkdate}">
@@ -1,5 +1,5 @@
 <?php
-// Shaarli 0.0.34 beta - Shaare your links...
+// Shaarli 0.0.35 beta - Shaare your links...
 // The personal, minimalist, super-fast, no-database delicious clone. By sebsauvage.net
 // http://sebsauvage.net/wiki/doku.php?id=php:shaarli